package com.jiuqi.script.rhino;

import com.jiuqi.script.IScriptObject;
import java.util.Calendar;
import java.util.Date;
import org.mozilla.javascript.Context;
import org.mozilla.javascript.IdFunctionObject;
import org.mozilla.javascript.IdScriptableObject;
import org.mozilla.javascript.NativeJavaObject;
import org.mozilla.javascript.Scriptable;
import org.mozilla.javascript.ScriptableObject;

public class ScriptHelper extends ScriptableObject {
   private Scriptable scope;

   ScriptHelper(Scriptable scope) {
      this.scope = scope;
      super.setParentScope(scope);
   }

   public Object toJava(Object obj) {
      return _toJava(obj, this.scope);
   }

   public Object toScript(Object obj) {
      return _toScript(obj, this.scope);
   }

   public void print(Object obj) {
      System.out.println(obj);
   }

   public String getClassName() {
      return "ScriptUtil";
   }

   static Object _toJava(Object obj, Scriptable scope) {
      if (obj == null) {
         return null;
      } else if (obj instanceof RhinoScriptObject) {
         return ((RhinoScriptObject)obj).getScriptObject();
      } else if (obj instanceof NativeJavaObject) {
         Object o = ((NativeJavaObject)obj).unwrap();
         return o instanceof RhinoScriptObject ? ((RhinoScriptObject)o).getScriptObject() : o;
      } else if (!(obj instanceof IdScriptableObject)) {
         return obj;
      } else {
         IdScriptableObject result = (IdScriptableObject)obj;
         if (result.getClassName().equals("Date")) {
            IdFunctionObject v = (IdFunctionObject)ScriptableObject.getProperty(result, "getTime");
            Object m = result.execIdCall(v, Context.getCurrentContext(), scope, result, (Object[])null);
            long millis = ((Double)m).longValue();
            Calendar c = Calendar.getInstance();
            c.setTimeInMillis(millis);
            return c;
         } else {
            return result;
         }
      }
   }

   static Object _toScript(Object obj, Scriptable scope) {
      if (obj == null) {
         return null;
      } else if (obj instanceof IScriptObject) {
         return new RhinoScriptObject((IScriptObject)obj);
      } else if (obj instanceof IdScriptableObject) {
         return obj;
      } else {
         if (obj instanceof NativeJavaObject) {
            Object result = ((NativeJavaObject)obj).unwrap();
            if (result instanceof IScriptObject) {
               return new RhinoScriptObject((IScriptObject)result);
            }

            if (result instanceof Calendar) {
               Calendar c = (Calendar)result;
               return Context.getCurrentContext().newObject(scope, "Date", new Object[]{new Long(c.getTimeInMillis())});
            }

            if (result instanceof Date) {
               Date d = (Date)result;
               return Context.getCurrentContext().newObject(scope, "Date", new Object[]{new Long(d.getTime())});
            }
         }

         return obj;
      }
   }
}
